@@ -4,4 +4,6 @@ from __future__ import division
 from pyslim.slim_metadata import *       # NOQA
 from pyslim.slim_tree_sequence import *  # NOQA
 from pyslim.provenance import *          # NOQA
+from pyslim.methods import *             # NOQA
+from pyslim.spatial import *             # NOQA
 from pyslim._version import pyslim_version as __version__
