@@ -1,3 +1,4 @@
+import warnings
 import numpy as np
 
 def unique_labels_by_group(group, label, minlength=0):
@@ -9,8 +10,14 @@ def unique_labels_by_group(group, label, minlength=0):
     return value will be of length at least ``minlength``.
 
     In other words, if the result is ``x``, then
-    ``x[j]`` is ``len(set(label[group == j])) == 1``.
+    ``x[j]`` is ``len(set(label[group == j])) <= 1``.
     '''
+    warnings.warn(
+            "The unique_labels_by_group( ) method is no longer used in pyslim, "
+            "so is now deprecated. Please copy the source code for your own use "
+            "if you wish to keep using it.",
+            FutureWarning,
+    )
     w = label.astype("float64")
     n = np.bincount(1 + group, minlength=minlength + 1)
     x = np.bincount(1 + group, weights=w, minlength=minlength + 1)
@@ -20,4 +27,4 @@ def unique_labels_by_group(group, label, minlength=0):
     w -= xm[1 + group]
     gw = np.bincount(1 + group, weights=np.abs(w), minlength=minlength + 1)[1:]
     # after subtracting groupwise means, should be all zero
-    return np.logical_and(n[1:] > 0, np.abs(gw) < 1e-7)
+    return np.abs(gw) < 1e-7
